========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   installation
   philosophy
   usage
   contributing
   api
   changelog
   authors

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

